==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/enums/OperationProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Defines values for OperationProvisioningState.
 */
public enum class OperationProvisioningState(
    public val javaValue: com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState> {
    Unknown(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Unknown),
    InProgress(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.InProgress),
    Succeeded(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Succeeded),
    Failed(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Failed),
    Canceled(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Canceled),
    Pending(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Pending),
    Disabled(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Disabled),
    ;

    override fun toJava(): com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState):
            OperationProvisioningState =
            OperationProvisioningState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/enums/OperationProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Defines values for OperationProvisioningState.
 */
public enum class OperationProvisioningState(
    public val javaValue: com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState> {
    Unknown(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Unknown),
    InProgress(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.InProgress),
    Succeeded(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Succeeded),
    Failed(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Failed),
    Canceled(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Canceled),
    Pending(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Pending),
    Disabled(com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState.Disabled),
    ;

    override fun toJava(): com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.notificationhubs.enums.OperationProvisioningState): OperationProvisioningState =
            OperationProvisioningState.values().first { it.javaValue == javaType }
    }
}
